@@ -71,7 +71,7 @@ Basic commands:
     %(b)sp%(R)s %(m)snumber%(R)s: Go to page %(m)snumber%(R)s in paged options.
     %(b)sh%(R)s: List history of databases and activities viewed.
     %(b)swh%(R)s: Write history to a text file.
-    %(b)sautosave%(R)s: Toggle autosave behaviour: saves current data.activity.
+    %(b)sautosave%(R)s: Toggle autosave behaviour on and off.
 
 Working with databases:
     %(b)sldb%(R)s: List available databases.
@@ -571,15 +571,13 @@ Autosave is turned %(autosave)s.""" % _({'dd': config.dir,
             self.choose_activity(key)
 
     def do_s(self, arg):
-        """Search activity names.
-
-        TODO: Ignore case."""
+        """Search activity names."""
         if not self.database:
             cprint("%(r)sNo current database%(R)s" % _({}))
         elif not arg:
             cprint("%(r)sMust provide search string%(R)s" % _({}))
         else:
-            results = Database(self.database).query(Filter('name', 'in', arg))
+            results = Database(self.database).query(Filter('name', 'ihas', arg))
             self.set_current_options({
                 'type': 'activities',
                 'options': results.keys(),
